ewa.clisupport.RecursiveChangedMp3FileIterator

Package ewa :: Module clisupport :: Class RecursiveChangedMp3FileIterator |
[hide private]
[frames] | no frames]

# Class RecursiveChangedMp3FileIterator

source code

                  object --+
                           |
    RecursiveMp3FileIterator --+
                               |
                              RecursiveChangedMp3FileIterator

Instance Methods | [hide private]
__init__(self, files, basedir, max_age=0) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_walk(self, f) | source code
Inherited from `RecursiveMp3FileIterator`: `__iter__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, files, basedir, max_age=0) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### _walk(self, f) | source code
Overrides: RecursiveMp3FileIterator._walk